sequencetools.is_integer_equivalent_n_tuple
===========================================

.. autofunction:: abjad.tools.sequencetools.is_integer_equivalent_n_tuple.is_integer_equivalent_n_tuple
   :noindex:
